'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

/**
 * ASP.NET Core CSRF Token Input Name
 *
 * @memberof jsForms
 * @name aspNetCoreCsrf
 * @type {string}
 */
var aspNetCoreCsrf = "__RequestVerificationToken";

var _const = /*#__PURE__*/Object.freeze({
  __proto__: null,
  aspNetCoreCsrf: aspNetCoreCsrf
});

function _slicedToArray(arr, i) {
  return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
}

function _arrayWithHoles(arr) {
  if (Array.isArray(arr)) return arr;
}

function _iterableToArrayLimit(arr, i) {
  if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
    return;
  }

  var _arr = [];
  var _n = true;
  var _d = false;
  var _e = undefined;

  try {
    for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
      _arr.push(_s.value);

      if (i && _arr.length === i) break;
    }
  } catch (err) {
    _d = true;
    _e = err;
  } finally {
    try {
      if (!_n && _i["return"] != null) _i["return"]();
    } finally {
      if (_d) throw _e;
    }
  }

  return _arr;
}

function _nonIterableRest() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance");
}

/*
 * Internal Helper Methods
 */

/**
 * Creates an HTML Form in memory, with named text inputs for the provided formData
 *
 * @memberof jsForms
 * @private
 * @param {string} action The url to use as a Form Action
 * @param {object} formData Keys/values to submit as named Form input fields
 * @returns {HTMLFormElement} The created form
 */
var createFormWithData = function createFormWithData(action, formData) {
  //create a new hidden form to submit
  var form = document.createElement("form");
  form.action = action;
  form.method = "post";
  form.style.display = "none"; //add the extra values in naive inputs

  for (var key in formData) {
    if (!formData.hasOwnProperty(key)) continue;
    var e = document.createElement("input");
    e.name = key;
    e.setAttribute("value", formData[key]);
    form.appendChild(e);
  }

  return form;
};
/**
 * Adds an in memory HTML Form to the DOM and immediately submits it
 *
 * @memberof jsForms
 * @private
 * @param {HTMLFormElement} form
 */

var submitForm = function submitForm(form) {
  //add it to the DOM and submit
  document.querySelector("body").appendChild(form);
  form.submit();
};

/**
 * Get data from a given form in the DOM, wrap the fields in a formData object,
 * unless the keys are in separates, in which case keep them separate from the formData object
 *
 * @memberof jsForms
 * @param {string} formSelector A CSS selector to find the form in the DOM
 * @param {...string} separates a ...array of keys to keep named form inputs separate from the formData object
 * @return {object} An object containing keys and values for `separates`
 * and all the other data of the specified form wrapped in a `formData` property.
 */

var getFormDataAsObject = function getFormDataAsObject(formSelector) {
  var form = document.querySelector(formSelector);
  var result = {
    formData: {}
  };

  for (var _len = arguments.length, separates = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    separates[_key - 1] = arguments[_key];
  }

  var _iteratorNormalCompletion = true;
  var _didIteratorError = false;
  var _iteratorError = undefined;

  try {
    for (var _iterator = new FormData(form)[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
      var _step$value = _slicedToArray(_step.value, 2),
          key = _step$value[0],
          value = _step$value[1];

      if (separates.includes(key)) //separate out the requested keys
        result[key] = value;else result.formData[key] = value; //else chuck them into the formData object
    }
  } catch (err) {
    _didIteratorError = true;
    _iteratorError = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion && _iterator["return"] != null) {
        _iterator["return"]();
      }
    } finally {
      if (_didIteratorError) {
        throw _iteratorError;
      }
    }
  }

  return result;
};
/**
 * Post a Form with the form inputs wrapped into a single json object, submitted as a single named string
 * Any extraValues are submitted in addition to the json string
 *
 * @memberof jsForms
 * @param {string} action The url to use as a Form Action
 * @param {string} jsonFieldName The name to give the input field containing the json string
 * @param {object} formData The object to turn into the json string value
 * @param {object} extraValues extra keys/values that each get their own input field in the final form
 */

var postFormDataAsJson = function postFormDataAsJson(action, jsonFieldName, formData, extraValues) {
  var form = createFormWithData(action, extraValues); //add the json data item

  var json = document.createElement("input");
  json.name = jsonFieldName;
  json.setAttribute("value", JSON.stringify(formData));
  form.appendChild(json); //add it to the DOM and submit

  submitForm(form);
};
/**
 * Create and submit an in memory form with the provided formData object as input fields
 *
 * @memberof jsForms
 * @param {string} action
 * @param {object} formData
 */

var postObjectAsFormData = function postObjectAsFormData(action, formData) {
  var form = createFormWithData(action, formData);
  submitForm(form);
};

exports.constants = _const;
exports.getFormDataAsObject = getFormDataAsObject;
exports.postFormDataAsJson = postFormDataAsJson;
exports.postObjectAsFormData = postObjectAsFormData;
//# sourceMappingURL=js-forms.js.map
